# -*- mode: Perl; -*-
# Before `make install' is performed this script should be runnable with
# `make test'. After `make install' it should work as `perl test.pl'

######################### We start with some black magic to print on failure.

# Change 1..1 below to 1..last_test_to_print .
# (It may become useful if the test is moved to ./t subdirectory.)


use Test::More tests=>11;
use strict;
use Data::Dumper;


BEGIN {use_ok('DNSSEC::Registry::Trust_DB'); }         # test 1

my $trustdb=DNSSEC::Registry::Trust_DB->new("test.foo");

ok($trustdb,"TrustDB created");
is($trust_db_err,"No Error", "Correct error message returned");

#  Remove any existing DB file otherwise some of these tests fail
#
$trustdb->_Delete_DB() ;                   


use Net::DNS;
my $keyrr=Net::DNS::RR->new(
		       "a.test.foo.	600	IN	DNSKEY	256  3  1 ( 
			AQO088/mqG4hzGzg6kjpZUCeUTBlDhpgqjWT
			GaE2ELLhqScSOy8WzRSw/YGog7a8XqOjtoBP
			rQsT6vtR6dJ/CBeK7fupPGiJn0Ec0QvT6u4V
			dXndvWYCU+i36gTqmsIMVoC542JnDa9hjWCz
			gyVAyz5kIU8Nvsgcx/JafIPeTbqnQQ== 
			) ");





my $keyrr1=Net::DNS::RR->new(
		       "b.test.foo.	600	IN	DNSKEY	256  3  1 ( 
			AQO088/mqG4hzGzg6kjpZUCeUTBlDhpgqjWT
			GaE2ELLhqScSOy8WzRSw/YGog7a8XqOjtoBP
			rQsT6vtR6dJ/CBeK7fupPGiJn0Ec0QvT6u4V
			dXndvWYCU+i36gTqmsIMVoC542JnDa9hjWCz
			gyVAyz5kIU8Nvsgcx/JafIPeTbqnQQ== 
			) ");

my $keyrr2=Net::DNS::RR->new(
		       "c.test.foo.	600	IN	DNSKEY	256  3  1 ( 
			AQO088/mqG4hzGzg6kjpZUCeUTBlDhpgqjWT
			GaE2ELLhqScSOy8WzRSw/YGog7a8XqOjtoBP
			rQsT6vtR6dJ/CBeK7fupPGiJn0Ec0QvT6u4V
			dXndvWYCU+i36gTqmsIMVoC542JnDa9hjWCz
			gyVAyz5kIU8Nvsgcx/JafIPeTbqnQQ== 
			) ");

# This key is outside the test.foo namespace. should fail to load in
#the DB.

my $keyrr4=Net::DNS::RR->new(
		       "c.foo.	600	IN	DNSKEY	256  3  3 ( 
			AQO088/mqG4hzGzg6kjpZUCeUTBlDhpgqjWT
			GaE2ELLhqScSOy8WzRSw/YGog7a8XqOjtoBP
			rQsT6vtR6dJ/CBeK7fupPGiJn0Ec0QvT6u4V
			dXndvWYCU+i36gTqmsIMVoC542JnDa9hjWCz
			gyVAyz5kIU8Nvsgcx/JafIPeTbqnQQ== 
			) ");


# Key 5 and key 6 have exactly the same key-tag/algorithm but differ
# in keymaterial.

my $keyrr5=Net::DNS::RR->new("
twokeys.test.foo. IN DNSKEY 256 3 1 
    AQPSC8I/+940fWMqkA+b/HV4xQW2IU86hUIMd2doDJWawoPtvghjr/M2 
    /vD9oRgxUxqBeRQkY+iJOvR5/cqcBQ9Z
			     ");



my $keyrr6=Net::DNS::RR->new("
twokeys.test.foo. IN DNSKEY 256 3 1 
  AQOZ6ERPX8Co+BFBQlZJp0DEC69CLQ6871yvObEHClEFhS2GzPqxixaz 
 n7KhP/44icFW+gFVHpWkPgdLtXayBQ/t
			     ");



my $trustobj=DNSSEC::Registry::Trust_Container->new($keyrr);
my $trustobj1=DNSSEC::Registry::Trust_Container->new($keyrr1);
my $trustobj2=DNSSEC::Registry::Trust_Container->new($keyrr2);
my $trustobj4=DNSSEC::Registry::Trust_Container->new($keyrr4);
my $trustobj5=DNSSEC::Registry::Trust_Container->new($keyrr5);
my $trustobj6=DNSSEC::Registry::Trust_Container->new($keyrr6);


$trustdb->store($trustobj);
$trustdb->store($trustobj1);
$trustdb->store($trustobj2);
is($trust_db_err,"No Error","No Error after successful load");   


$trustdb->store($trustobj4);
is($trust_db_err,"The trust container is not in the test\\.foo namespace","Trust object outside namespace failed to load");                    
$trustdb->store($trustobj5);
$trustdb->store($trustobj6);

is ($trust_db_err, "Non revoked key with same domain key_id and algorithm in DB", "Same key Domain-Algo-ID refused if the other is not revoked");  
$trustobj5->set_revoked;  
#  Store the revoked object again.
#

$trustdb->store($trustobj5);

#print Dumper $trustobj5;
is ($trust_db_err, "No Error", 
    "Restoring object after truststate was changed");  

$trustdb->store($trustobj6);

is ($trust_db_err, "No Error", 
    "Storing same domain-alg-keytag triplet with revoked object");   # test 6



my @trustobj=$trustdb->get("c.test.foo");
ok ($trustdb->in_db($trustobj5),"Key found in key DB");	           # test 7

##
##  Artificially expire the object .. Remember that t_start was set as object
##  creation and defaulted to 'now'

$trustobj6->set_t_start($trustobj6->get_t_creation-5);
$trustobj6->set_t_end($trustobj6->get_t_creation-3);
$trustdb->store($trustobj6);
my @expired_trust=$trustdb->get_expired();

is (@expired_trust+0,1,"Proper number of expired RRs returned");
is ( @expired_trust[0]->identifyer, $trustobj6->identifyer, "Proper Expired object returned");

